Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/GuardLabelImpl.java')
-rw-r--r--extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/GuardLabelImpl.java123
1 files changed, 67 insertions, 56 deletions
diff --git a/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/GuardLabelImpl.java b/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/GuardLabelImpl.java
index 1630dbd56ac..24f0b163eda 100644
--- a/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/GuardLabelImpl.java
+++ b/extraplugins/diagram-definition/org.eclipse.papyrus.umldi/src-gen/org/eclipse/papyrus/umldi/impl/GuardLabelImpl.java
@@ -13,16 +13,12 @@ package org.eclipse.papyrus.umldi.impl;
import org.eclipse.emf.common.notify.Notification;
import org.eclipse.emf.common.notify.NotificationChain;
-
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.InternalEObject;
-
import org.eclipse.emf.ecore.impl.ENotificationImpl;
-
import org.eclipse.emf.ecore.util.EcoreUtil;
-
+import org.eclipse.papyrus.umldi.ActivityEdgeEdge;
import org.eclipse.papyrus.umldi.GuardLabel;
-import org.eclipse.papyrus.umldi.RelationshipWithGuardEdge;
import org.eclipse.papyrus.umldi.UMLDIPackage;
import org.eclipse.papyrus.umldi.UmlDiagramElement;
@@ -34,16 +30,18 @@ import org.eclipse.papyrus.umldi.UmlDiagramElement;
* The following features are implemented:
* </p>
* <ul>
* <li>{@link org.eclipse.papyrus.umldi.impl.GuardLabelImpl#getOwningUmlDiagramElement <em>Owning Uml Diagram Element</em>}</li>
* <li>{@link org.eclipse.papyrus.umldi.impl.GuardLabelImpl#getRelationshipWithGuardEdge <em>Relationship With Guard Edge</em>}</li>
* </ul>
*
* @generated
*/
public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
+
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
protected GuardLabelImpl() {
@@ -53,6 +51,7 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
@@ -63,6 +62,7 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
@@ -74,13 +74,14 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public UmlDiagramElement basicGetOwningUmlDiagramElement() {
- RelationshipWithGuardEdge relationshipWithGuardEdge = getRelationshipWithGuardEdge();
- if (relationshipWithGuardEdge != null) {
- return relationshipWithGuardEdge;
+ ActivityEdgeEdge activityEdgeEdge = getActivityEdgeEdge();
+ if(activityEdgeEdge != null) {
+ return activityEdgeEdge;
}
return super.basicGetOwningUmlDiagramElement();
}
@@ -88,56 +89,61 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
- public RelationshipWithGuardEdge getRelationshipWithGuardEdge() {
- if (eContainerFeatureID() != UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE) return null;
- return (RelationshipWithGuardEdge)eInternalContainer();
+ public ActivityEdgeEdge getActivityEdgeEdge() {
+ if(eContainerFeatureID() != UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE)
+ return null;
+ return (ActivityEdgeEdge)eInternalContainer();
}
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
- public NotificationChain basicSetRelationshipWithGuardEdge(RelationshipWithGuardEdge newRelationshipWithGuardEdge, NotificationChain msgs) {
- msgs = eBasicSetContainer((InternalEObject)newRelationshipWithGuardEdge, UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE, msgs);
+ public NotificationChain basicSetActivityEdgeEdge(ActivityEdgeEdge newActivityEdgeEdge, NotificationChain msgs) {
+ msgs = eBasicSetContainer((InternalEObject)newActivityEdgeEdge, UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE, msgs);
return msgs;
}
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
- public void setRelationshipWithGuardEdge(RelationshipWithGuardEdge newRelationshipWithGuardEdge) {
- if (newRelationshipWithGuardEdge != eInternalContainer() || (eContainerFeatureID() != UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE && newRelationshipWithGuardEdge != null)) {
- if (EcoreUtil.isAncestor(this, newRelationshipWithGuardEdge))
+ public void setActivityEdgeEdge(ActivityEdgeEdge newActivityEdgeEdge) {
+ if(newActivityEdgeEdge != eInternalContainer() || (eContainerFeatureID() != UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE && newActivityEdgeEdge != null)) {
+ if(EcoreUtil.isAncestor(this, newActivityEdgeEdge))
throw new IllegalArgumentException("Recursive containment not allowed for " + toString());
NotificationChain msgs = null;
- if (eInternalContainer() != null)
+ if(eInternalContainer() != null)
msgs = eBasicRemoveFromContainer(msgs);
- if (newRelationshipWithGuardEdge != null)
- msgs = ((InternalEObject)newRelationshipWithGuardEdge).eInverseAdd(this, UMLDIPackage.RELATIONSHIP_WITH_GUARD_EDGE__GUARD_LABEL, RelationshipWithGuardEdge.class, msgs);
- msgs = basicSetRelationshipWithGuardEdge(newRelationshipWithGuardEdge, msgs);
- if (msgs != null) msgs.dispatch();
- }
- else if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE, newRelationshipWithGuardEdge, newRelationshipWithGuardEdge));
+ if(newActivityEdgeEdge != null)
+ msgs = ((InternalEObject)newActivityEdgeEdge).eInverseAdd(this, UMLDIPackage.ACTIVITY_EDGE_EDGE__GUARD_LABEL, ActivityEdgeEdge.class, msgs);
+ msgs = basicSetActivityEdgeEdge(newActivityEdgeEdge, msgs);
+ if(msgs != null)
+ msgs.dispatch();
+ } else if(eNotificationRequired())
+ eNotify(new ENotificationImpl(this, Notification.SET, UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE, newActivityEdgeEdge, newActivityEdgeEdge));
}
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public NotificationChain eInverseAdd(InternalEObject otherEnd, int featureID, NotificationChain msgs) {
- switch (featureID) {
- case UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE:
- if (eInternalContainer() != null)
- msgs = eBasicRemoveFromContainer(msgs);
- return basicSetRelationshipWithGuardEdge((RelationshipWithGuardEdge)otherEnd, msgs);
+ switch(featureID) {
+ case UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE:
+ if(eInternalContainer() != null)
+ msgs = eBasicRemoveFromContainer(msgs);
+ return basicSetActivityEdgeEdge((ActivityEdgeEdge)otherEnd, msgs);
}
return super.eInverseAdd(otherEnd, featureID, msgs);
}
@@ -145,13 +151,14 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public NotificationChain eInverseRemove(InternalEObject otherEnd, int featureID, NotificationChain msgs) {
- switch (featureID) {
- case UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE:
- return basicSetRelationshipWithGuardEdge(null, msgs);
+ switch(featureID) {
+ case UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE:
+ return basicSetActivityEdgeEdge(null, msgs);
}
return super.eInverseRemove(otherEnd, featureID, msgs);
}
@@ -159,13 +166,14 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public NotificationChain eBasicRemoveFromContainerFeature(NotificationChain msgs) {
- switch (eContainerFeatureID()) {
- case UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE:
- return eInternalContainer().eInverseRemove(this, UMLDIPackage.RELATIONSHIP_WITH_GUARD_EDGE__GUARD_LABEL, RelationshipWithGuardEdge.class, msgs);
+ switch(eContainerFeatureID()) {
+ case UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE:
+ return eInternalContainer().eInverseRemove(this, UMLDIPackage.ACTIVITY_EDGE_EDGE__GUARD_LABEL, ActivityEdgeEdge.class, msgs);
}
return super.eBasicRemoveFromContainerFeature(msgs);
}
@@ -173,13 +181,14 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public Object eGet(int featureID, boolean resolve, boolean coreType) {
- switch (featureID) {
- case UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE:
- return getRelationshipWithGuardEdge();
+ switch(featureID) {
+ case UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE:
+ return getActivityEdgeEdge();
}
return super.eGet(featureID, resolve, coreType);
}
@@ -187,14 +196,15 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public void eSet(int featureID, Object newValue) {
- switch (featureID) {
- case UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE:
- setRelationshipWithGuardEdge((RelationshipWithGuardEdge)newValue);
- return;
+ switch(featureID) {
+ case UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE:
+ setActivityEdgeEdge((ActivityEdgeEdge)newValue);
+ return;
}
super.eSet(featureID, newValue);
}
@@ -202,14 +212,15 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public void eUnset(int featureID) {
- switch (featureID) {
- case UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE:
- setRelationshipWithGuardEdge((RelationshipWithGuardEdge)null);
- return;
+ switch(featureID) {
+ case UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE:
+ setActivityEdgeEdge((ActivityEdgeEdge)null);
+ return;
}
super.eUnset(featureID);
}
@@ -217,15 +228,16 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public boolean eIsSet(int featureID) {
- switch (featureID) {
- case UMLDIPackage.GUARD_LABEL__OWNING_UML_DIAGRAM_ELEMENT:
- return isSetOwningUmlDiagramElement();
- case UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE:
- return getRelationshipWithGuardEdge() != null;
+ switch(featureID) {
+ case UMLDIPackage.GUARD_LABEL__OWNING_UML_DIAGRAM_ELEMENT:
+ return isSetOwningUmlDiagramElement();
+ case UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE:
+ return getActivityEdgeEdge() != null;
}
return super.eIsSet(featureID);
}
@@ -233,12 +245,11 @@ public class GuardLabelImpl extends UmlLabelImpl implements GuardLabel {
/**
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
+ *
* @generated
*/
@Override
public boolean isSetOwningUmlDiagramElement() {
- return super.isSetOwningUmlDiagramElement()
- || eIsSet(UMLDIPackage.GUARD_LABEL__RELATIONSHIP_WITH_GUARD_EDGE);
+ return super.isSetOwningUmlDiagramElement() || eIsSet(UMLDIPackage.GUARD_LABEL__ACTIVITY_EDGE_EDGE);
}
-
} //GuardLabelImpl

Back to the top
@@ -34,16 +30,18 @@ import org.eclipse.papyrus.umldi.UmlDiagramElement;
* </p>
* <ul>
- * <li>{@link org.eclipse.papyrus.umldi.impl.GuardLabelImpl#getOwningUmlDiagramElement <em>Owning Uml Diagram Element</em>}</li>
- * <li>{@link org.eclipse.papyrus.umldi.impl.GuardLabelImpl#getRelationshipWithGuardEdge <em>Relationship With Guard Edge</em>}</li>
+ * <li>{@link org.eclipse.papyrus.umldi.impl.GuardLabelImpl#getOwningUmlDiagramElement <em>Owning Uml Diagram Element</em>}</li>
+ * <li>{@link org.eclipse.papyrus.umldi.impl.GuardLabelImpl#getActivityEdgeEdge <em>Activity Edge Edge</em>}</li>
* </ul>
*